package SQ.Columns.Databanks;

import com.strategyquant.lib.*;
import com.strategyquant.datalib.*;
import com.strategyquant.tradinglib.*;

public class Efficiency extends DatabankColumn {
    
	public Efficiency() {
		super("Efficiency", 
          DatabankColumn.Decimal2Pct, // value display format
          ValueTypes.Maximize, // whether value should be maximized / minimized / approximated to a value   
          0, // target value if approximation was chosen  
          -100, // average minimum of this value
          100); // average maximum of this value
		
    setWidth(80); // defaultcolumn width in pixels
    
		setTooltip("Efficiency of trading strategy. Net profit divided by Gross profit");
        
    setDependencies("GrossProfit", "GrossLoss");
	}
  
  //------------------------------------------------------------------------

  /**
   * This method should return computed value of this new column. You should typically compute it from the list of orders 
   * or from some already computed statistical values (other databank columns). 
   */
	@Override
	public double compute(SQStats stats, StatsTypeCombination combination, OrdersList ordersList, SettingsMap settings, SQStats statsLong, SQStats statsShort) throws Exception {
    
    double sumProfits = stats.getDouble("GrossProfit");
		double sumLosses = stats.getDouble("GrossLoss");

		return SQUtils.round2(SQUtils.safeDivide(sumProfits - sumLosses, sumProfits) * 100);

	}	
}